#ifndef _BSS_1D_CODE_GENERATOR_H_
#define _BSS_1D_CODE_GENERATOR_H_


/*
// Import/Export support
*/

#if defined(_MSC_VER) && defined(_BSS_1D_DLL)
#if defined(_BSS_1D_EXPORTS)
#define BSS_DLL __declspec(dllexport)
#else
#define BSS_DLL __declspec(dllimport)
#endif
#else
#define BSS_DLL
#endif

#ifdef __cplusplus
extern "C" {
#endif


/*
// Definitions of return codes
*/

#define BSSG_1D_CODE_OK                 ( 0)
#define BSSG_1D_CODE_ERR_GENERIC        (-1)
#define BSSG_1D_CODE_ERR_OUTOFMEMORY    (-2)
#define BSSG_1D_CODE_ERR_NOTSUPPORTED   (-3)
#define BSSG_1D_CODE_ERR_INVALIDARGS    (-4)
#define BSSG_1D_CODE_ERR_OUTOFSYMBOLOGY (-5)


/*
// Supported barcode types
*/

#define BSS_CODE39                (1) /* Code39  barcode                          */
#define BSS_CODE128               (2) /* Code128 barcode                          */
#define BSS_EAN13                 (3) /* EAN-13  barcode                          */
#define BSS_EAN8                  (4) /* EAN-8   barcode                          */
#define BSS_CODABAR               (5) /* Codabar barcode                          */
#define BSS_INT2OF5               (6) /* Interleaved 2 of 5 barcode               */
#define BSS_ID_2OF5               (7) /* 2 of 5  barcode                          */


/* 
// Generate 1D barcode symbol
*/
BSS_DLL int BSS_Generate1DCode
(
    const char*        pchData,       /* Barcode data for encoding                */
    int                nDataLength,   /* Barcode data length                      */
    int                nCodeType,     /* Barcode type identifier                  */
    int                nModSize,      /* Barcode module size (in pixels)          */
    int                nImgRowDist,   /* Desired row distance multiplier          */
    void**             ppImgData,     /* Pointer to image data pointer            */
    int*               pnImgWidth,    /* Pointer to image width                   */
    int*               pnImgHeight,   /* Pointer to image height                  */
    int*               pnImgRowDist   /* Pointer to distance between image's rows */
);

/* 
// TODO
*/
BSS_DLL int BSS_Release1DCodeImage
(
    void*              pImgData,      /* Pointer to barcode's image data          */
    int                nImgWidth,     /* Image width                              */
    int                nImgHeight,    /* Image height                             */
    int                nImgRowDist    /* Distance between image's rows (in bytes) */
);

#ifdef __cplusplus
}       /* extern "C" */
#endif

#endif /* _BSS_1D_CODE_GENERATOR_H_ */
